@@ -3,7 +3,7 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
 {
   call <- match.call()
   
-  ######### Validation des arguments en entre et initialisations #########
+  ######### Validation des arguments en entree et initialisations #########
   
   valid.one(dfreq,"logical")
   dtype <- dtype[1]
@@ -11,10 +11,10 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
   valid.t(t=t, pInf=FALSE)
   Xvalid <- valid.X(X=X, dfreq=dfreq, dtype=dtype, t=t)
     X <- Xvalid$X
-    t <- Xvalid$t  ## t est modifi s'il prennait la valeur NULL ou Inf
+    t <- Xvalid$t  ## t est modifie s'il prennait la valeur NULL ou Inf
   m <- valid.vm(vm=m, values=c("M0","Mt","Mh","Mth","Mb","Mbh"), vt=t, typet=TRUE)
-  typet <- if(m %in% c("M0", "Mh")) FALSE else TRUE  ## si VRAI, alors t0 n'est pas utilis   
-  t0 <- valid.t0(t0=t0, typet=typet, t=t) ## doit tre soumis aprs valid.X qui modifie t
+  typet <- if(m %in% c("M0", "Mh")) FALSE else TRUE  ## si VRAI, alors t0 n'est pas utilise   
+  t0 <- valid.t0(t0=t0, typet=typet, t=t) ## doit etre soumis apres valid.X qui modifie t
   valid.h.out <- valid.h(h=h, values=c("Chao","LB","Poisson","Darroch","Gamma"), m=m, call=call)
     h <- valid.h.out$h
     htype <- valid.h.out$htype
@@ -22,10 +22,10 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
   theta <- valid.theta(theta = h.control$theta, htype = htype)
   neg <- valid.neg(neg = h.control$neg, htype = htype)
   
-  #### Initialisation du nom du modle
+  #### Initialisation du nom du modele
   mname <- valid.mname(mname=NULL, m=m, htype=htype, theta=theta, call=call)         
   
-  #### Certains modles ne peuvent tre ajusts par closedp.bc
+  #### Certains modeles ne peuvent etre ajustes par closedp.bc
   if (dtype=="nbcap" && m%in%c("Mt","Mth","Mb","Mbh")) 
     stop("'X' cannot be of type 'nbcap' for models Mt, Mth, Mb and Mbh") 
   if( m == "Mbh" && t < 4 ) 
@@ -57,7 +57,7 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
       m2 <- ni[1] + ni[2] - n
       N <- (ni[1]+1)*(ni[2]+1)/(m2+1) - 1
       erreurtype <- sqrt((ni[1]+1)*(ni[2]+1)*(ni[1]-m2)*(ni[2]-m2)/((m2+2)*(m2+1)^2))
-    } else { # Seber p.131 et 133 avec correction des frquences selon Rivest & Lvesque 2001
+    } else { # Seber p.131 et 133 avec correction des frequences selon Rivest & Levesque 2001
       Nprelim <- closedpCI.0(X=X,dfreq=dfreq,m="M0")$results[1,1]
       ni.corr <- ni + (t+2)/(2*t)
       n.corr <- n + t/2
@@ -91,13 +91,13 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
       
     indicglm <- TRUE
     
-    ### laboration prliminaire du modle
+    ### elaboration preliminaire du modele
     if (m %in% c("Mb", "Mbh")) {
       Y <- getui(X=X, dfreq=dfreq, t=t)
       if(m=="Mbh") { omitY <- Y[1]; Y <- Y[-1]} 
       mX. <- if(m=="Mb") matrix(0:(t-1), ncol = 1) else matrix(0:(t-2), ncol = 1)
       colnames(mX.) <- "beta"
-      nca <- ncol(mX.)  ## En ralit cette valeur ne sera pas utilise
+      nca <- ncol(mX.)  ## En realite cette valeur ne sera pas utilisee
       cst <- rep(0,length(Y))
     } else {
       getmX.out <- getmX(typet=typet, t=t, t0=t0, m=m, h=h, theta=theta)
@@ -107,7 +107,7 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
       cst <- getcst(typet=typet, tinf=FALSE, t=t, t0=t0, nbcap=nbcap)
     }
     
-    ### Ajustement des frquences
+    ### Ajustement des frequences
     delta <- rep(0,length(Y))
     if (m %in% c("Mb", "Mbh")) {
       delta[1] <- +2
@@ -136,18 +136,18 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
     }
     Yd <- pmax(0,Y + delta)
     
-    ### Ajustement du modle
+    ### Ajustement du modele
     fit.out <- closedp.fitone(n = n, Y = Yd, mX. = mX., nbcap = nbcap, nca = nca, 
                               cst = cst, htype = htype, neg = neg, ...)
     
-    # On arrte la fonction si l'ajustement n'a pas fonctionn
+    # On arrete la fonction si l'ajustement n'a pas fonctionne
     if (!is.null(fit.out$fit.err)) stop("error when fitting the model: ", fit.out$fit.err)
     
     # Sinon, on peut poursuivre les calculs
     glmo <- fit.out$fit
     glmo.warn <- fit.out$fit.warnings
     
-    # on retire les warnings pour les valeurs de Y non entires : ... "non-integer" ...
+    # on retire les warnings pour les valeurs de Y non entieres : ... "non-integer" ...
     tokeep <- !grepl("non-integer", glmo.warn, fixed = TRUE)
     glmo.warn <- glmo.warn[tokeep]
     if (length(glmo.warn)==0) glmo.warn <- NULL
@@ -171,7 +171,7 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
     
   }
   
-  # Prparation des sorties
+  # Preparation des sorties
   results <- matrix(c(N, erreurtype, infoFit), 1, 3)
   dimnames(results) <- list(mname, c("abundance", "stderr", "infoFit")) 
   
@@ -180,7 +180,7 @@ closedp.bc <- function(X, dfreq=FALSE, dtype=c("hist","nbcap"), t=NULL, t0=t,
     # Si on a fait un calcul exact (Mt ou Mh Chao), on n'a pas besoin de 
     # conserver une trace des warnings, ceux-ci sont impossibles.    
     ans <- c(ans, list(glm.warn=glmo.warn))
-    # ID eta negatif enlevs si modle Mth Chao
+    # ID eta negatif enleves si modele Mth Chao
     if (htype == "Chao") ans <- c(ans, fit.out["neg.eta"])
   }
   if (typet) ans$t0 <- NULL
